class PDFUtil:
    @staticmethod
    def get_pdf_data(target_source):
        raise NotImplementedError("PDF to text conversion is not implemented yet")
        # with open(pdf_file, 'wb') as file:
        #     file.write(pdf_file)
        #
        # reader = PdfReader(pdf_file)
        # text = []
        #
        # for page in reader.pages:
        #     text.append(page.extract_text())
        #
        # return "\n".join(text)
